@@ -1,11 +1,9 @@
 package Tags;
 
-# Pragmas.
 use strict;
 use warnings;
 
-# Version.
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 
 1;
 
@@ -62,13 +60,13 @@ L<https://github.com/tupinek/Tags>
 
 =head1 AUTHOR
 
-Michal Špaček L<mailto:skim@cpan.org>
+Michal Josef Špaček L<mailto:skim@cpan.org>
 
 L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2005-2016 Michal Špaček
+ © 2005-2018 Michal Josef Špaček
  BSD 2-Clause License
 
 =head1 VERSION 
